[SCM] WebKit Debian packaging branch, debian/experimental, updated. upstream/1.3.3-9427-gc2be6fc

darin at apple.com darin at apple.com
Wed Dec 22 15:17:25 UTC 2010


The following commit has been merged in the debian/experimental branch:
commit 75bbaed842f3f2ba7c22130a241f55093e83137a
Author: darin at apple.com <darin at apple.com@268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Fri Oct 29 21:38:12 2010 +0000

    2010-10-29  Darin Adler  <darin at apple.com>
    
            Reviewed by Sam Weinig.
    
            Change BackForwardList clients to use BackForwardListImpl to prepare for further refactoring
            https://bugs.webkit.org/show_bug.cgi?id=48574
    
            * src/BackForwardListClientImpl.h: Use BackForwardListImpl.h.
            * src/WebViewImpl.cpp:
            (WebKit::WebViewImpl::WebViewImpl): Cast to BackForwardList* before calling setClient.
    2010-10-29  Darin Adler  <darin at apple.com>
    
            Reviewed by Sam Weinig.
    
            Change BackForwardList clients to use BackForwardListImpl to prepare for further refactoring
            https://bugs.webkit.org/show_bug.cgi?id=48574
    
            * Api/qwebhistory.cpp:
            (QWebHistory::clear):
            * Api/qwebhistory_p.h:
            * Api/qwebpage.cpp:
            (QWebPagePrivate::QWebPagePrivate):
            Use BackForwardListImpl.
    2010-10-29  Darin Adler  <darin at apple.com>
    
            Reviewed by Sam Weinig.
    
            Change BackForwardList clients to use BackForwardListImpl to prepare for further refactoring
            https://bugs.webkit.org/show_bug.cgi?id=48574
    
            * webkit/webkitprivate.h:
            * webkit/webkitwebbackforwardlist.cpp:
            (webkit_web_back_forward_list_dispose):
            (webkit_web_back_forward_list_new_with_web_view):
            (webkit_web_back_forward_list_go_forward):
            (webkit_web_back_forward_list_go_back):
            (webkit_web_back_forward_list_contains_item):
            (webkit_web_back_forward_list_go_to_item):
            (webkit_web_back_forward_list_get_forward_list_with_limit):
            (webkit_web_back_forward_list_get_back_list_with_limit):
            (webkit_web_back_forward_list_get_back_item):
            (webkit_web_back_forward_list_get_current_item):
            (webkit_web_back_forward_list_get_forward_item):
            (webkit_web_back_forward_list_get_nth_item):
            (webkit_web_back_forward_list_get_back_length):
            (webkit_web_back_forward_list_get_forward_length):
            (webkit_web_back_forward_list_get_limit):
            (webkit_web_back_forward_list_set_limit):
            (webkit_web_back_forward_list_add_item):
            (webkit_web_back_forward_list_clear):
            (WebKit::core):
            * webkit/webkitwebview.cpp:
            (webkit_web_view_set_maintains_back_forward_list):
            (webkit_web_view_get_back_forward_list):
            Use BackForwardListImpl.
    2010-10-29  Darin Adler  <darin at apple.com>
    
            Reviewed by Sam Weinig.
    
            Change BackForwardList clients to use BackForwardListImpl to prepare for further refactoring
            https://bugs.webkit.org/show_bug.cgi?id=48574
    
            * WebBackForwardList.cpp:
            (backForwardListWrappers):
            (WebBackForwardList::WebBackForwardList):
            (WebBackForwardList::createInstance):
            * WebBackForwardList.h:
            * WebView.cpp:
            (WebView::backForwardList):
            Use BackForwardListImpl.
    2010-10-29  Darin Adler  <darin at apple.com>
    
            Reviewed by Sam Weinig.
    
            Change BackForwardList clients to use BackForwardListImpl to prepare for further refactoring
            https://bugs.webkit.org/show_bug.cgi?id=48574
    
            * WebFrame.cpp:
            (wxWebFrame::CanGoBack): Use canGoBackOrForward.
            (wxWebFrame::CanGoForward): Ditto.
    2010-10-29  Darin Adler  <darin at apple.com>
    
            Reviewed by Sam Weinig.
    
            Change BackForwardList clients to use BackForwardListImpl to prepare for further refactoring
            https://bugs.webkit.org/show_bug.cgi?id=48574
    
            * History/WebBackForwardList.mm:
            Use BackForwardListImpl.
    2010-10-29  Darin Adler  <darin at apple.com>
    
            Reviewed by Sam Weinig.
    
            Change BackForwardList clients to use BackForwardListImpl to prepare for further refactoring
            https://bugs.webkit.org/show_bug.cgi?id=48574
    
            * ewk/ewk_history.cpp:
            (ewk_history_new):
            * ewk/ewk_private.h:
            * ewk/ewk_view.cpp:
            (_ewk_view_priv_new):
            (ewk_view_history_enable_get):
            (ewk_view_history_enable_set):
            (ewk_view_history_get):
            Use BackForwardListImpl.
    
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@70931 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebKit/chromium/ChangeLog b/WebKit/chromium/ChangeLog
index 54a3fc5..9eeb48b 100644
--- a/WebKit/chromium/ChangeLog
+++ b/WebKit/chromium/ChangeLog
@@ -1,3 +1,14 @@
+2010-10-29  Darin Adler  <darin at apple.com>
+
+        Reviewed by Sam Weinig.
+
+        Change BackForwardList clients to use BackForwardListImpl to prepare for further refactoring
+        https://bugs.webkit.org/show_bug.cgi?id=48574
+
+        * src/BackForwardListClientImpl.h: Use BackForwardListImpl.h.
+        * src/WebViewImpl.cpp:
+        (WebKit::WebViewImpl::WebViewImpl): Cast to BackForwardList* before calling setClient.
+
 2010-10-28  Michael Nordman  <michaeln at google.com>
 
         Reviewed by ap.
diff --git a/WebKit/chromium/src/BackForwardListClientImpl.h b/WebKit/chromium/src/BackForwardListClientImpl.h
index 38e37a4..b795ecf 100644
--- a/WebKit/chromium/src/BackForwardListClientImpl.h
+++ b/WebKit/chromium/src/BackForwardListClientImpl.h
@@ -31,7 +31,7 @@
 #ifndef BackForwardListClientImpl_h
 #define BackForwardListClientImpl_h
 
-#include "BackForwardList.h"
+#include "BackForwardListImpl.h"
 
 namespace WebKit {
 class WebViewImpl;
diff --git a/WebKit/chromium/src/WebViewImpl.cpp b/WebKit/chromium/src/WebViewImpl.cpp
index 6782a23..57d0ca4 100644
--- a/WebKit/chromium/src/WebViewImpl.cpp
+++ b/WebKit/chromium/src/WebViewImpl.cpp
@@ -33,6 +33,7 @@
 
 #include "AutoFillPopupMenuClient.h"
 #include "AXObjectCache.h"
+#include "BackForwardListImpl.h"
 #include "Chrome.h"
 #include "ColorSpace.h"
 #include "CompositionUnderlineVectorBuilder.h"
@@ -312,7 +313,7 @@ WebViewImpl::WebViewImpl(WebViewClient* client, WebDevToolsAgentClient* devTools
 
     m_page.set(new Page(pageClients));
 
-    m_page->backForwardList()->setClient(&m_backForwardListClientImpl);
+    static_cast<BackForwardListImpl*>(m_page->backForwardList())->setClient(&m_backForwardListClientImpl);
     m_page->setGroupName(pageGroupName);
 
     m_inspectorSettingsMap.set(new SettingsMap);
diff --git a/WebKit/efl/ChangeLog b/WebKit/efl/ChangeLog
index bbbfbad..bf9af1e 100644
--- a/WebKit/efl/ChangeLog
+++ b/WebKit/efl/ChangeLog
@@ -1,3 +1,20 @@
+2010-10-29  Darin Adler  <darin at apple.com>
+
+        Reviewed by Sam Weinig.
+
+        Change BackForwardList clients to use BackForwardListImpl to prepare for further refactoring
+        https://bugs.webkit.org/show_bug.cgi?id=48574
+
+        * ewk/ewk_history.cpp:
+        (ewk_history_new):
+        * ewk/ewk_private.h:
+        * ewk/ewk_view.cpp:
+        (_ewk_view_priv_new):
+        (ewk_view_history_enable_get):
+        (ewk_view_history_enable_set):
+        (ewk_view_history_get):
+        Use BackForwardListImpl.
+
 2010-10-29  Alexey Proskuryakov  <ap at apple.com>
 
         Reviewed by Darin Adler.
diff --git a/WebKit/efl/ewk/ewk_private.h b/WebKit/efl/ewk/ewk_private.h
index e2624a3..c1599e3 100644
--- a/WebKit/efl/ewk/ewk_private.h
+++ b/WebKit/efl/ewk/ewk_private.h
@@ -21,7 +21,7 @@
 #ifndef ewk_private_h
 #define ewk_private_h
 
-#include "BackForwardList.h"
+#include "BackForwardListImpl.h"
 #include "EWebKit.h"
 #include "Frame.h"
 #include "Page.h"
@@ -108,7 +108,7 @@ void ewk_view_download_request(Evas_Object *o, Ewk_Download *download);
 
 int ewk_view_dpi_get();
 
-Ewk_History *ewk_history_new(WebCore::BackForwardList *history);
+Ewk_History *ewk_history_new(WebCore::BackForwardListImpl *history);
 void ewk_history_free(Ewk_History *history);
 
 Ewk_Context_Menu *ewk_context_menu_new(Evas_Object *view, WebCore::ContextMenuController *controller);
diff --git a/WebKit/efl/ewk/ewk_view.cpp b/WebKit/efl/ewk/ewk_view.cpp
index f1ca733..5ff3ade 100644
--- a/WebKit/efl/ewk/ewk_view.cpp
+++ b/WebKit/efl/ewk/ewk_view.cpp
@@ -22,6 +22,7 @@
 #include "config.h"
 #include "ewk_view.h"
 
+#include "BackForwardListImpl.h"
 #include "Chrome.h"
 #include "ChromeClientEfl.h"
 #include "ContextMenuClientEfl.h"
@@ -634,7 +635,7 @@ static Ewk_View_Private_Data* _ewk_view_priv_new(Ewk_View_Smart_Data* sd)
         goto error_main_frame;
     }
 
-    priv->history = ewk_history_new(priv->page->backForwardList());
+    priv->history = ewk_history_new(static_cast<WebCore::BackForwardListImpl*>(priv->page->backForwardList()));
     if (!priv->history) {
         CRITICAL("Could not create history instance for view.");
         goto error_history;
@@ -1762,7 +1763,7 @@ Eina_Bool ewk_view_history_enable_get(const Evas_Object* o)
 {
     EWK_VIEW_SD_GET_OR_RETURN(o, sd, EINA_FALSE);
     EWK_VIEW_PRIV_GET_OR_RETURN(sd, priv, EINA_FALSE);
-    return priv->page->backForwardList()->enabled();
+    return static_cast<WebCore::BackForwardListImpl*>(priv->page->backForwardList())->enabled();
 }
 
 /**
@@ -1778,7 +1779,7 @@ Eina_Bool ewk_view_history_enable_set(Evas_Object* o, Eina_Bool enable)
 {
     EWK_VIEW_SD_GET_OR_RETURN(o, sd, EINA_FALSE);
     EWK_VIEW_PRIV_GET_OR_RETURN(sd, priv, EINA_FALSE);
-    priv->page->backForwardList()->setEnabled(enable);
+    static_cast<WebCore::BackForwardListImpl*>(priv->page->backForwardList())->setEnabled(enable);
     return EINA_TRUE;
 }
 
@@ -1802,7 +1803,7 @@ Ewk_History* ewk_view_history_get(const Evas_Object* o)
 {
     EWK_VIEW_SD_GET_OR_RETURN(o, sd, 0);
     EWK_VIEW_PRIV_GET_OR_RETURN(sd, priv, 0);
-    if (!priv->page->backForwardList()->enabled()) {
+    if (!static_cast<WebCore::BackForwardListImpl*>(priv->page->backForwardList())->enabled()) {
         ERR("asked history, but it's disabled! Returning 0!");
         return 0;
     }
diff --git a/WebKit/gtk/ChangeLog b/WebKit/gtk/ChangeLog
index 6af6639..cd11751 100644
--- a/WebKit/gtk/ChangeLog
+++ b/WebKit/gtk/ChangeLog
@@ -1,3 +1,36 @@
+2010-10-29  Darin Adler  <darin at apple.com>
+
+        Reviewed by Sam Weinig.
+
+        Change BackForwardList clients to use BackForwardListImpl to prepare for further refactoring
+        https://bugs.webkit.org/show_bug.cgi?id=48574
+
+        * webkit/webkitprivate.h:
+        * webkit/webkitwebbackforwardlist.cpp:
+        (webkit_web_back_forward_list_dispose):
+        (webkit_web_back_forward_list_new_with_web_view):
+        (webkit_web_back_forward_list_go_forward):
+        (webkit_web_back_forward_list_go_back):
+        (webkit_web_back_forward_list_contains_item):
+        (webkit_web_back_forward_list_go_to_item):
+        (webkit_web_back_forward_list_get_forward_list_with_limit):
+        (webkit_web_back_forward_list_get_back_list_with_limit):
+        (webkit_web_back_forward_list_get_back_item):
+        (webkit_web_back_forward_list_get_current_item):
+        (webkit_web_back_forward_list_get_forward_item):
+        (webkit_web_back_forward_list_get_nth_item):
+        (webkit_web_back_forward_list_get_back_length):
+        (webkit_web_back_forward_list_get_forward_length):
+        (webkit_web_back_forward_list_get_limit):
+        (webkit_web_back_forward_list_set_limit):
+        (webkit_web_back_forward_list_add_item):
+        (webkit_web_back_forward_list_clear):
+        (WebKit::core):
+        * webkit/webkitwebview.cpp:
+        (webkit_web_view_set_maintains_back_forward_list):
+        (webkit_web_view_get_back_forward_list):
+        Use BackForwardListImpl.
+
 2010-10-29  Alexey Proskuryakov  <ap at apple.com>
 
         Reviewed by Darin Adler.
diff --git a/WebKit/gtk/webkit/webkitprivate.h b/WebKit/gtk/webkit/webkitprivate.h
index 01b9a4e..261c437 100644
--- a/WebKit/gtk/webkit/webkitprivate.h
+++ b/WebKit/gtk/webkit/webkitprivate.h
@@ -46,7 +46,7 @@
 #include <webkit/webkitsecurityorigin.h>
 
 #include "ArchiveResource.h"
-#include "BackForwardList.h"
+#include "BackForwardListImpl.h"
 #include "DataObjectGtk.h"
 #include "DragActions.h"
 #include "Frame.h"
@@ -92,7 +92,7 @@ namespace WebKit {
     WebCore::HistoryItem* core(WebKitWebHistoryItem*);
     WebKitWebHistoryItem* kit(PassRefPtr<WebCore::HistoryItem>);
 
-    WebCore::BackForwardList* core(WebKitWebBackForwardList*);
+    WebCore::BackForwardListImpl* core(WebKitWebBackForwardList*);
 
     WebKitWebNavigationReason kit(WebCore::NavigationType type);
     WebCore::NavigationType core(WebKitWebNavigationReason reason);
diff --git a/WebKit/gtk/webkit/webkitwebbackforwardlist.cpp b/WebKit/gtk/webkit/webkitwebbackforwardlist.cpp
index 4789de9..c5913fd 100644
--- a/WebKit/gtk/webkit/webkitwebbackforwardlist.cpp
+++ b/WebKit/gtk/webkit/webkitwebbackforwardlist.cpp
@@ -27,7 +27,7 @@
 
 #include <glib.h>
 
-#include "BackForwardList.h"
+#include "BackForwardListImpl.h"
 #include "HistoryItem.h"
 
 /**
@@ -53,7 +53,7 @@
 using namespace WebKit;
 
 struct _WebKitWebBackForwardListPrivate {
-    WebCore::BackForwardList* backForwardList;
+    WebCore::BackForwardListImpl* backForwardList;
     gboolean disposed;
 };
 
@@ -64,7 +64,7 @@ G_DEFINE_TYPE(WebKitWebBackForwardList, webkit_web_back_forward_list, G_TYPE_OBJ
 static void webkit_web_back_forward_list_dispose(GObject* object)
 {
     WebKitWebBackForwardList* list = WEBKIT_WEB_BACK_FORWARD_LIST(object);
-    WebCore::BackForwardList* backForwardList = core(list);
+    WebCore::BackForwardListImpl* backForwardList = core(list);
     WebKitWebBackForwardListPrivate* priv = list->priv;
 
     if (!priv->disposed) {
@@ -115,7 +115,7 @@ WebKitWebBackForwardList* webkit_web_back_forward_list_new_with_web_view(WebKitW
     webBackForwardList = WEBKIT_WEB_BACK_FORWARD_LIST(g_object_new(WEBKIT_TYPE_WEB_BACK_FORWARD_LIST, NULL));
     WebKitWebBackForwardListPrivate* priv = webBackForwardList->priv;
 
-    priv->backForwardList = core(webView)->backForwardList();
+    priv->backForwardList = static_cast<BackForwardListImpl*>(core(webView)->backForwardList());
     priv->backForwardList->setEnabled(TRUE);
 
     return webBackForwardList;
@@ -131,7 +131,7 @@ void webkit_web_back_forward_list_go_forward(WebKitWebBackForwardList* webBackFo
 {
     g_return_if_fail(WEBKIT_IS_WEB_BACK_FORWARD_LIST(webBackForwardList));
 
-    WebCore::BackForwardList* backForwardList = core(webBackForwardList);
+    WebCore::BackForwardListImpl* backForwardList = core(webBackForwardList);
     if (backForwardList->enabled())
         backForwardList->goForward();
 }
@@ -146,7 +146,7 @@ void webkit_web_back_forward_list_go_back(WebKitWebBackForwardList* webBackForwa
 {
     g_return_if_fail(WEBKIT_IS_WEB_BACK_FORWARD_LIST(webBackForwardList));
 
-    WebCore::BackForwardList* backForwardList = core(webBackForwardList);
+    WebCore::BackForwardListImpl* backForwardList = core(webBackForwardList);
     if (backForwardList->enabled())
         backForwardList->goBack();
 }
@@ -169,7 +169,7 @@ gboolean webkit_web_back_forward_list_contains_item(WebKitWebBackForwardList* we
 
     g_return_val_if_fail(historyItem != NULL, FALSE);
 
-    WebCore::BackForwardList* backForwardList = core(webBackForwardList);
+    WebCore::BackForwardListImpl* backForwardList = core(webBackForwardList);
 
     return (backForwardList->enabled() ? backForwardList->containsItem(historyItem) : FALSE);
 }
@@ -187,7 +187,7 @@ void webkit_web_back_forward_list_go_to_item(WebKitWebBackForwardList* webBackFo
     g_return_if_fail(WEBKIT_IS_WEB_HISTORY_ITEM(webHistoryItem));
 
     WebCore::HistoryItem* historyItem = core(webHistoryItem);
-    WebCore::BackForwardList* backForwardList = core(webBackForwardList);
+    WebCore::BackForwardListImpl* backForwardList = core(webBackForwardList);
 
     if (backForwardList->enabled() && historyItem)
         backForwardList->goToItem(historyItem);
@@ -206,7 +206,7 @@ GList* webkit_web_back_forward_list_get_forward_list_with_limit(WebKitWebBackFor
 {
     g_return_val_if_fail(WEBKIT_IS_WEB_BACK_FORWARD_LIST(webBackForwardList), NULL);
 
-    WebCore::BackForwardList* backForwardList = core(webBackForwardList);
+    WebCore::BackForwardListImpl* backForwardList = core(webBackForwardList);
     if (!backForwardList || !backForwardList->enabled())
         return NULL;
 
@@ -236,7 +236,7 @@ GList* webkit_web_back_forward_list_get_back_list_with_limit(WebKitWebBackForwar
 {
     g_return_val_if_fail(WEBKIT_IS_WEB_BACK_FORWARD_LIST(webBackForwardList), NULL);
 
-    WebCore::BackForwardList* backForwardList = core(webBackForwardList);
+    WebCore::BackForwardListImpl* backForwardList = core(webBackForwardList);
     if (!backForwardList || !backForwardList->enabled())
         return NULL;
 
@@ -265,7 +265,7 @@ WebKitWebHistoryItem* webkit_web_back_forward_list_get_back_item(WebKitWebBackFo
 {
     g_return_val_if_fail(WEBKIT_IS_WEB_BACK_FORWARD_LIST(webBackForwardList), NULL);
 
-    WebCore::BackForwardList* backForwardList = core(webBackForwardList);
+    WebCore::BackForwardListImpl* backForwardList = core(webBackForwardList);
     if (!backForwardList || !backForwardList->enabled())
         return NULL;
 
@@ -288,7 +288,7 @@ WebKitWebHistoryItem* webkit_web_back_forward_list_get_current_item(WebKitWebBac
 {
     g_return_val_if_fail(WEBKIT_IS_WEB_BACK_FORWARD_LIST(webBackForwardList), NULL);
 
-    WebCore::BackForwardList* backForwardList = core(webBackForwardList);
+    WebCore::BackForwardListImpl* backForwardList = core(webBackForwardList);
     if (!backForwardList || !backForwardList->enabled())
         return NULL;
 
@@ -311,7 +311,7 @@ WebKitWebHistoryItem* webkit_web_back_forward_list_get_forward_item(WebKitWebBac
 {
     g_return_val_if_fail(WEBKIT_IS_WEB_BACK_FORWARD_LIST(webBackForwardList), NULL);
 
-    WebCore::BackForwardList* backForwardList = core(webBackForwardList);
+    WebCore::BackForwardListImpl* backForwardList = core(webBackForwardList);
     if (!backForwardList || !backForwardList->enabled())
         return NULL;
 
@@ -333,7 +333,7 @@ WebKitWebHistoryItem* webkit_web_back_forward_list_get_nth_item(WebKitWebBackFor
 {
     g_return_val_if_fail(WEBKIT_IS_WEB_BACK_FORWARD_LIST(webBackForwardList), NULL);
 
-    WebCore::BackForwardList* backForwardList = core(webBackForwardList);
+    WebCore::BackForwardListImpl* backForwardList = core(webBackForwardList);
     if (!backForwardList)
         return NULL;
 
@@ -354,7 +354,7 @@ gint webkit_web_back_forward_list_get_back_length(WebKitWebBackForwardList* webB
 {
     g_return_val_if_fail(WEBKIT_IS_WEB_BACK_FORWARD_LIST(webBackForwardList), 0);
 
-    WebCore::BackForwardList* backForwardList = core(webBackForwardList);
+    WebCore::BackForwardListImpl* backForwardList = core(webBackForwardList);
     if (!backForwardList || !backForwardList->enabled())
         return 0;
 
@@ -373,7 +373,7 @@ gint webkit_web_back_forward_list_get_forward_length(WebKitWebBackForwardList* w
 {
     g_return_val_if_fail(WEBKIT_IS_WEB_BACK_FORWARD_LIST(webBackForwardList), 0);
 
-    WebCore::BackForwardList* backForwardList = core(webBackForwardList);
+    WebCore::BackForwardListImpl* backForwardList = core(webBackForwardList);
     if (!backForwardList || !backForwardList->enabled())
         return 0;
 
@@ -392,7 +392,7 @@ gint webkit_web_back_forward_list_get_limit(WebKitWebBackForwardList* webBackFor
 {
     g_return_val_if_fail(WEBKIT_IS_WEB_BACK_FORWARD_LIST(webBackForwardList), 0);
 
-    WebCore::BackForwardList* backForwardList = core(webBackForwardList);
+    WebCore::BackForwardListImpl* backForwardList = core(webBackForwardList);
     if (!backForwardList || !backForwardList->enabled())
         return 0;
 
@@ -412,7 +412,7 @@ void webkit_web_back_forward_list_set_limit(WebKitWebBackForwardList* webBackFor
 {
     g_return_if_fail(WEBKIT_IS_WEB_BACK_FORWARD_LIST(webBackForwardList));
 
-    WebCore::BackForwardList* backForwardList = core(webBackForwardList);
+    WebCore::BackForwardListImpl* backForwardList = core(webBackForwardList);
     if (backForwardList)
         backForwardList->setCapacity(limit);
 }
@@ -435,7 +435,7 @@ void webkit_web_back_forward_list_add_item(WebKitWebBackForwardList *webBackForw
 
     g_object_ref(webHistoryItem);
 
-    WebCore::BackForwardList* backForwardList = core(webBackForwardList);
+    WebCore::BackForwardListImpl* backForwardList = core(webBackForwardList);
     WebCore::HistoryItem* historyItem = core(webHistoryItem);
 
     backForwardList->addItem(historyItem);
@@ -454,7 +454,7 @@ void webkit_web_back_forward_list_clear(WebKitWebBackForwardList* webBackForward
 {
     g_return_if_fail(WEBKIT_IS_WEB_BACK_FORWARD_LIST(webBackForwardList));
 
-    WebCore::BackForwardList* backForwardList = core(webBackForwardList);
+    WebCore::BackForwardListImpl* backForwardList = core(webBackForwardList);
     if (!backForwardList || !backForwardList->enabled() || !backForwardList->entries().size())
         return;
 
@@ -464,7 +464,7 @@ void webkit_web_back_forward_list_clear(WebKitWebBackForwardList* webBackForward
     backForwardList->setCapacity(capacity);
 }
 
-WebCore::BackForwardList* WebKit::core(WebKitWebBackForwardList* webBackForwardList)
+WebCore::BackForwardListImpl* WebKit::core(WebKitWebBackForwardList* webBackForwardList)
 {
     g_return_val_if_fail(WEBKIT_IS_WEB_BACK_FORWARD_LIST(webBackForwardList), NULL);
 
diff --git a/WebKit/gtk/webkit/webkitwebview.cpp b/WebKit/gtk/webkit/webkitwebview.cpp
index e12f7ff..a295fce 100644
--- a/WebKit/gtk/webkit/webkitwebview.cpp
+++ b/WebKit/gtk/webkit/webkitwebview.cpp
@@ -42,7 +42,7 @@
 
 #include "AXObjectCache.h"
 #include "AbstractDatabase.h"
-#include "BackForwardList.h"
+#include "BackForwardListImpl.h"
 #include "Cache.h"
 #include "ChromeClientGtk.h"
 #include "ClipboardUtilitiesGtk.h"
@@ -3431,7 +3431,7 @@ void webkit_web_view_set_maintains_back_forward_list(WebKitWebView* webView, gbo
 {
     g_return_if_fail(WEBKIT_IS_WEB_VIEW(webView));
 
-    core(webView)->backForwardList()->setEnabled(flag);
+    static_cast<BackForwardListImpl*>(core(webView)->backForwardList())->setEnabled(flag);
 }
 
 /**
@@ -3446,7 +3446,7 @@ void webkit_web_view_set_maintains_back_forward_list(WebKitWebView* webView, gbo
 WebKitWebBackForwardList* webkit_web_view_get_back_forward_list(WebKitWebView* webView)
 {
     g_return_val_if_fail(WEBKIT_IS_WEB_VIEW(webView), 0);
-    if (!core(webView) || !core(webView)->backForwardList()->enabled())
+    if (!core(webView) || !static_cast<BackForwardListImpl*>(core(webView)->backForwardList())->enabled())
         return 0;
     return webView->priv->backForwardList.get();
 }
diff --git a/WebKit/mac/ChangeLog b/WebKit/mac/ChangeLog
index f5d43ff..e7abf3d 100644
--- a/WebKit/mac/ChangeLog
+++ b/WebKit/mac/ChangeLog
@@ -1,3 +1,13 @@
+2010-10-29  Darin Adler  <darin at apple.com>
+
+        Reviewed by Sam Weinig.
+
+        Change BackForwardList clients to use BackForwardListImpl to prepare for further refactoring
+        https://bugs.webkit.org/show_bug.cgi?id=48574
+
+        * History/WebBackForwardList.mm:
+        Use BackForwardListImpl.
+
 2010-10-29  Alexey Proskuryakov  <ap at apple.com>
 
         Rubber-stamped by Sam Weinig.
diff --git a/WebKit/mac/History/WebBackForwardList.mm b/WebKit/mac/History/WebBackForwardList.mm
index 45fa7e9..e794c2f 100644
--- a/WebKit/mac/History/WebBackForwardList.mm
+++ b/WebKit/mac/History/WebBackForwardList.mm
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005, 2007 Apple Inc.  All rights reserved.
+ * Copyright (C) 2005, 2007 Apple Inc. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -53,8 +53,10 @@
 
 using namespace WebCore;
 
-typedef HashMap<BackForwardList*, WebBackForwardList*> BackForwardListMap;
+typedef HashMap<BackForwardListImpl*, WebBackForwardList*> BackForwardListMap;
 
+// FIXME: Instead of this we could just create a class derived from BackForwardListImpl
+// with a pointer to a WebBackForwardList in it.
 static BackForwardListMap& backForwardLists()
 {
     DEFINE_STATIC_LOCAL(BackForwardListMap, staticBackForwardLists, ());
diff --git a/WebKit/qt/Api/qwebhistory_p.h b/WebKit/qt/Api/qwebhistory_p.h
index 1df2349..44793b9 100644
--- a/WebKit/qt/Api/qwebhistory_p.h
+++ b/WebKit/qt/Api/qwebhistory_p.h
@@ -20,7 +20,7 @@
 #ifndef QWEBHISTORY_P_H
 #define QWEBHISTORY_P_H
 
-#include "BackForwardList.h"
+#include "BackForwardListImpl.h"
 #include "HistoryItem.h"
 #include <QtCore/qglobal.h>
 #include <QtCore/qshareddata.h>
@@ -52,7 +52,7 @@ public:
 
 class QWebHistoryPrivate : public QSharedData {
 public:
-    QWebHistoryPrivate(WebCore::BackForwardList* l)
+    QWebHistoryPrivate(WebCore::BackForwardListImpl* l)
     {
         l->ref();
         lst = l;
@@ -64,7 +64,7 @@ public:
 
     QWebPagePrivate* page();
 
-    WebCore::BackForwardList* lst;
+    WebCore::BackForwardListImpl* lst;
 };
 
 
diff --git a/WebKit/qt/Api/qwebpage.cpp b/WebKit/qt/Api/qwebpage.cpp
index fa672b8..cf06726 100644
--- a/WebKit/qt/Api/qwebpage.cpp
+++ b/WebKit/qt/Api/qwebpage.cpp
@@ -33,70 +33,71 @@
 #include "qwebsettings.h"
 #include "qwebkitversion.h"
 
-#include "Chrome.h"
-#include "ContextMenuController.h"
-#include "Frame.h"
-#include "FrameTree.h"
-#include "FrameLoader.h"
-#include "FrameLoaderClientQt.h"
-#include "FrameView.h"
-#include "FormState.h"
 #include "ApplicationCacheStorage.h"
+#include "BackForwardListImpl.h"
+#include "Cache.h"
+#include "Chrome.h"
 #include "ChromeClientQt.h"
 #include "ContextMenu.h"
 #include "ContextMenuClientQt.h"
+#include "ContextMenuController.h"
 #include "DeviceMotionClientQt.h"
 #include "DeviceOrientationClientQt.h"
 #include "DocumentLoader.h"
 #include "DragClientQt.h"
 #include "DragController.h"
 #include "DragData.h"
+#include "Editor.h"
 #include "EditorClientQt.h"
-#include "SchemeRegistry.h"
-#include "SecurityOrigin.h"
-#include "Settings.h"
-#include "Page.h"
-#include "Pasteboard.h"
-#include "FrameLoader.h"
+#include "FocusController.h"
+#include "FormState.h"
+#include "Frame.h"
 #include "FrameLoadRequest.h"
-#include "KURL.h"
-#include "Logging.h"
+#include "FrameLoader.h"
+#include "FrameLoader.h"
+#include "FrameLoaderClientQt.h"
+#include "FrameTree.h"
+#include "FrameView.h"
+#include "GeolocationPermissionClientQt.h"
+#include "HTMLFormElement.h"
+#include "HTMLInputElement.h"
+#include "HTMLNames.h"
+#include "HashMap.h"
+#include "HitTestResult.h"
 #include "Image.h"
 #include "InspectorClientQt.h"
 #include "InspectorController.h"
-#include "FocusController.h"
-#include "Editor.h"
-#include "Scrollbar.h"
+#include "InspectorServerQt.h"
+#include "KURL.h"
+#include "LocalizedStrings.h"
+#include "Logging.h"
+#include "MIMETypeRegistry.h"
 #include "NavigationAction.h"
 #include "NetworkingContext.h"
+#include "NotificationPresenterClientQt.h"
+#include "Page.h"
+#include "PageClientQt.h"
+#include "PageGroup.h"
+#include "Pasteboard.h"
 #include "PlatformKeyboardEvent.h"
+#include "PlatformTouchEvent.h"
 #include "PlatformWheelEvent.h"
 #include "PluginDatabase.h"
+#include "PluginDatabase.h"
+#include "PluginPackage.h"
 #include "ProgressTracker.h"
 #include "RefPtr.h"
 #include "RenderTextControl.h"
+#include "SchemeRegistry.h"
+#include "Scrollbar.h"
+#include "SecurityOrigin.h"
+#include "Settings.h"
 #include "TextIterator.h"
-#include "HashMap.h"
-#include "HTMLFormElement.h"
-#include "HTMLInputElement.h"
-#include "HTMLNames.h"
-#include "HitTestResult.h"
-#include "InspectorServerQt.h"
-#include "WindowFeatures.h"
 #include "WebPlatformStrategies.h"
-#include "LocalizedStrings.h"
-#include "Cache.h"
-#include "runtime/InitializeThreading.h"
-#include "PageGroup.h"
-#include "GeolocationPermissionClientQt.h"
-#include "NotificationPresenterClientQt.h"
-#include "PageClientQt.h"
-#include "PlatformTouchEvent.h"
+#include "WindowFeatures.h"
 #include "WorkerThread.h"
+#include "runtime/InitializeThreading.h"
 #include "wtf/Threading.h"
-#include "MIMETypeRegistry.h"
-#include "PluginDatabase.h"
-#include "PluginPackage.h"
 
 #include <QApplication>
 #include <QBasicTimer>
@@ -312,7 +313,7 @@ QWebPagePrivate::QWebPagePrivate(QWebPage *qq)
 
     settings = new QWebSettings(page->settings());
 
-    history.d = new QWebHistoryPrivate(page->backForwardList());
+    history.d = new QWebHistoryPrivate(static_cast<WebCore::BackForwardListImpl*>(page->backForwardList()));
     memset(actions, 0, sizeof(actions));
 
     PageGroup::setShouldTrackVisitedLinks(true);
diff --git a/WebKit/qt/ChangeLog b/WebKit/qt/ChangeLog
index 0dc808e..c2dcad8 100644
--- a/WebKit/qt/ChangeLog
+++ b/WebKit/qt/ChangeLog
@@ -1,3 +1,17 @@
+2010-10-29  Darin Adler  <darin at apple.com>
+
+        Reviewed by Sam Weinig.
+
+        Change BackForwardList clients to use BackForwardListImpl to prepare for further refactoring
+        https://bugs.webkit.org/show_bug.cgi?id=48574
+
+        * Api/qwebhistory.cpp:
+        (QWebHistory::clear):
+        * Api/qwebhistory_p.h:
+        * Api/qwebpage.cpp:
+        (QWebPagePrivate::QWebPagePrivate):
+        Use BackForwardListImpl.
+
 2010-10-29  Alexey Proskuryakov  <ap at apple.com>
 
         Reviewed by Darin Adler.
diff --git a/WebKit/win/ChangeLog b/WebKit/win/ChangeLog
index 27f6ec7..fb8f19e 100644
--- a/WebKit/win/ChangeLog
+++ b/WebKit/win/ChangeLog
@@ -1,3 +1,19 @@
+2010-10-29  Darin Adler  <darin at apple.com>
+
+        Reviewed by Sam Weinig.
+
+        Change BackForwardList clients to use BackForwardListImpl to prepare for further refactoring
+        https://bugs.webkit.org/show_bug.cgi?id=48574
+
+        * WebBackForwardList.cpp:
+        (backForwardListWrappers):
+        (WebBackForwardList::WebBackForwardList):
+        (WebBackForwardList::createInstance):
+        * WebBackForwardList.h:
+        * WebView.cpp:
+        (WebView::backForwardList):
+        Use BackForwardListImpl.
+
 2010-10-29  Adam Roben  <aroben at apple.com>
 
         Windows build fix
diff --git a/WebKit/win/WebBackForwardList.cpp b/WebKit/win/WebBackForwardList.cpp
index e8c2930..2faaf7e 100644
--- a/WebKit/win/WebBackForwardList.cpp
+++ b/WebKit/win/WebBackForwardList.cpp
@@ -32,7 +32,7 @@
 #include "WebKit.h"
 #include "WebPreferences.h"
 
-#include <WebCore/BackForwardList.h>
+#include <WebCore/BackForwardListImpl.h>
 #include <WebCore/HistoryItem.h>
 
 using std::min;
@@ -40,13 +40,15 @@ using namespace WebCore;
 
 // WebBackForwardList ----------------------------------------------------------------
 
-static HashMap<BackForwardList*, WebBackForwardList*>& backForwardListWrappers()
+// FIXME: Instead of this we could just create a class derived from BackForwardListImpl
+// with a pointer to a WebBackForwardList in it.
+static HashMap<BackForwardListImpl*, WebBackForwardList*>& backForwardListWrappers()
 {
-    static HashMap<BackForwardList*, WebBackForwardList*> staticBackForwardListWrappers;
+    static HashMap<BackForwardListImpl*, WebBackForwardList*> staticBackForwardListWrappers;
     return staticBackForwardListWrappers;
 }
 
-WebBackForwardList::WebBackForwardList(PassRefPtr<BackForwardList> backForwardList)
+WebBackForwardList::WebBackForwardList(PassRefPtr<BackForwardListImpl> backForwardList)
     : m_refCount(0)
     , m_backForwardList(backForwardList)
 {
@@ -68,7 +70,7 @@ WebBackForwardList::~WebBackForwardList()
     gClassNameCount.remove("WebBackForwardList");
 }
 
-WebBackForwardList* WebBackForwardList::createInstance(PassRefPtr<BackForwardList> backForwardList)
+WebBackForwardList* WebBackForwardList::createInstance(PassRefPtr<BackForwardListImpl> backForwardList)
 {
     WebBackForwardList* instance;
 
diff --git a/WebKit/win/WebBackForwardList.h b/WebKit/win/WebBackForwardList.h
index 9375193..aebfa15 100644
--- a/WebKit/win/WebBackForwardList.h
+++ b/WebKit/win/WebBackForwardList.h
@@ -34,15 +34,15 @@
 #include <WTF/RefPtr.h>
 
 namespace WebCore {
-    class BackForwardList;
+    class BackForwardListImpl;
 }
 
 class WebBackForwardList : public IWebBackForwardList, IWebBackForwardListPrivate
 {
 public:
-    static WebBackForwardList* createInstance(PassRefPtr<WebCore::BackForwardList>);
+    static WebBackForwardList* createInstance(PassRefPtr<WebCore::BackForwardListImpl>);
 protected:
-    WebBackForwardList(PassRefPtr<WebCore::BackForwardList>);
+    WebBackForwardList(PassRefPtr<WebCore::BackForwardListImpl>);
     ~WebBackForwardList();
 
 public:
@@ -109,7 +109,7 @@ public:
 
 protected:
     ULONG m_refCount;
-    RefPtr<WebCore::BackForwardList> m_backForwardList;
+    RefPtr<WebCore::BackForwardListImpl> m_backForwardList;
 };
 
 #endif
diff --git a/WebKit/win/WebView.cpp b/WebKit/win/WebView.cpp
index 2cc8e0c..fb62809 100644
--- a/WebKit/win/WebView.cpp
+++ b/WebKit/win/WebView.cpp
@@ -67,7 +67,7 @@
 #include <WebCore/AXObjectCache.h>
 #include <WebCore/ApplicationCacheStorage.h>
 #include <WebCore/BString.h>
-#include <WebCore/BackForwardList.h>
+#include <WebCore/BackForwardListImpl.h>
 #include <WebCore/BitmapInfo.h>
 #include <WebCore/Cache.h>
 #include <WebCore/Chrome.h>
@@ -2870,13 +2870,14 @@ HRESULT STDMETHODCALLTYPE WebView::focusedFrame(
 
     return webFrame->QueryInterface(IID_IWebFrame, (void**) frame);
 }
+
 HRESULT STDMETHODCALLTYPE WebView::backForwardList( 
     /* [out][retval] */ IWebBackForwardList** list)
 {
     if (!m_useBackForwardList)
         return E_FAIL;
  
-    *list = WebBackForwardList::createInstance(m_page->backForwardList());
+    *list = WebBackForwardList::createInstance(static_cast<WebCore::BackForwardListImpl*>(m_page->backForwardList()));
 
     return S_OK;
 }
diff --git a/WebKit/wx/ChangeLog b/WebKit/wx/ChangeLog
index 2fc2914..123b839 100644
--- a/WebKit/wx/ChangeLog
+++ b/WebKit/wx/ChangeLog
@@ -1,3 +1,14 @@
+2010-10-29  Darin Adler  <darin at apple.com>
+
+        Reviewed by Sam Weinig.
+
+        Change BackForwardList clients to use BackForwardListImpl to prepare for further refactoring
+        https://bugs.webkit.org/show_bug.cgi?id=48574
+
+        * WebFrame.cpp:
+        (wxWebFrame::CanGoBack): Use canGoBackOrForward.
+        (wxWebFrame::CanGoForward): Ditto.
+
 2010-10-29  Alexey Proskuryakov  <ap at apple.com>
 
         Reviewed by Darin Adler.
diff --git a/WebKit/wx/WebFrame.cpp b/WebKit/wx/WebFrame.cpp
index 1c2eebd..1d5f03a 100644
--- a/WebKit/wx/WebFrame.cpp
+++ b/WebKit/wx/WebFrame.cpp
@@ -24,7 +24,7 @@
  */
 
 #include "config.h"
-#include "BackForwardList.h"
+
 #include "Document.h"
 #include "Editor.h"
 #include "Element.h"
@@ -318,16 +318,16 @@ bool wxWebFrame::GoForward()
 
 bool wxWebFrame::CanGoBack()
 {
-    if (m_impl->frame && m_impl->frame->page() && m_impl->frame->page()->backForwardList())
-        return m_impl->frame->page()->backForwardList()->backItem() != NULL;
+    if (m_impl->frame && m_impl->frame->page())
+        return m_impl->frame->page()->canGoBackOrForward(-1);
 
     return false;
 }
 
 bool wxWebFrame::CanGoForward()
 {
-    if (m_impl->frame && m_impl->frame->page() && m_impl->frame->page()->backForwardList())
-        return m_impl->frame->page()->backForwardList()->forwardItem() != NULL;
+    if (m_impl->frame && m_impl->frame->page())
+        return m_impl->frame->page()->canGoBackOrForward(1);
 
     return false;
 }

diff --git a/WebKit/efl/ewk/ewk_history.cpp b/WebKit/efl/ewk/ewk_history.cpp
index 8387da1..0a9d349 100644
--- a/WebKit/efl/ewk/ewk_history.cpp
+++ b/WebKit/efl/ewk/ewk_history.cpp
@@ -21,7 +21,7 @@
 #include "config.h"
 #include "ewk_history.h"
 
-#include "BackForwardList.h"
+#include "BackForwardListImpl.h"
 #include "EWebKit.h"
 #include "HistoryItem.h"
 #include "Image.h"
@@ -32,7 +32,7 @@
 #include <eina_safety_checks.h>
 
 struct _Ewk_History {
-    WebCore::BackForwardList *core;
+    WebCore::BackForwardListImpl *core;
 };
 
 #define EWK_HISTORY_CORE_GET_OR_RETURN(history, core_, ...)      \
@@ -48,7 +48,7 @@ struct _Ewk_History {
         ERR("history->core is disabled!.");                      \
         return __VA_ARGS__;                                      \
     }                                                            \
-    WebCore::BackForwardList *core_ = (history)->core
+    WebCore::BackForwardListImpl *core_ = (history)->core
 
 
 struct _Ewk_History_Item {
@@ -666,11 +666,11 @@ Eina_Bool ewk_history_item_visit_last_failed(const Ewk_History_Item* item)
  * Creates history for given view. Called internally by ewk_view and
  * should never be called from outside.
  *
  * @param core WebCore::BackForwardList instance to use internally.
  *
  * @return newly allocated history instance or @c NULL on errors.
  */
-Ewk_History* ewk_history_new(WebCore::BackForwardList* core)
+Ewk_History* ewk_history_new(WebCore::BackForwardListImpl* core)
 {
     Ewk_History* history;
     EINA_SAFETY_ON_NULL_RETURN_VAL(core, 0);
@@ -666,11 +666,11 @@ Eina_Bool ewk_history_item_visit_last_failed(const Ewk_History_Item* item)
  * should never be called from outside.
  *
- * @param core WebCore::BackForwardList instance to use internally.
+ * @param core WebCore::BackForwardListImpl instance to use internally.
  *
  * @return newly allocated history instance or @c NULL on errors.
diff --git a/WebKit/qt/Api/qwebhistory.cpp b/WebKit/qt/Api/qwebhistory.cpp
index 25d77a4..a9761de 100644
--- a/WebKit/qt/Api/qwebhistory.cpp
+++ b/WebKit/qt/Api/qwebhistory.cpp
@@ -256,8 +256,8 @@ QWebHistory::~QWebHistory()
 */
 void QWebHistory::clear()
 {
-    //shortcut to private BackForwardList
-    WebCore::BackForwardList* lst = d->lst;
+    //shortcut to private BackForwardListImpl
+    WebCore::BackForwardListImpl* lst = d->lst;
 
     //clear visited links
     WebCore::Page* page = static_cast<WebCore::BackForwardListImpl*>(lst)->page();
-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list